@@ -1,3 +1,4 @@
+from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.mtv import MTV
 from ocp_resources.resource import NamespacedResource
 
@@ -18,6 +19,7 @@ class Hook(NamespacedResource, MTV):
         client=None,
         teardown=True,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
     ):
         """
         Args:
@@ -30,6 +32,7 @@ class Hook(NamespacedResource, MTV):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
         )
         self.image = image
         self.playbook = playbook
