@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import Resource
 
 
@@ -21,9 +21,14 @@ class HostPathProvisioner(Resource):
         client=None,
         teardown=True,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
     ):
         super().__init__(
-            name=name, client=client, teardown=teardown, yaml_file=yaml_file
+            name=name,
+            client=client,
+            teardown=teardown,
+            yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
         )
         self.path = path
         self.image_pull_policy = image_pull_policy
